package fetch

import (
	"bufio"
	"errors"
	"os"
	"strings"
)

const (
	versionFilePath          = "/proc/version"
	wordsBeforeKernelVersion = 2
)

func Kernel() (string, error) {
	file, err := os.Open(versionFilePath)
	if err != nil {
		return "", err
	}

	defer file.Close()

	scanner := bufio.NewScanner(file)
	if !scanner.Scan() {
		return "", scanner.Err()
	}

	line := scanner.Text()
	words := strings.Split(line, " ")
	if len(words) < wordsBeforeKernelVersion+1 {
		return "", errors.New("kernel version not found")
	}

	return words[wordsBeforeKernelVersion], nil
}
