//go:build arch_updates

package fetch

import (
	"fmt"
	"os"
	"strconv"
	"strings"
)

const (
	installedPkgsPath    = "/var/lib/pacman/local/"
	availableUpdatesPath = "/.cache/available_updates"
)

type PkgInfo struct {
	Installed        int
	AvailableUpdates int
}

func Pkgs() (*PkgInfo, error) {
	installed, err := listPkgsPacman()
	if err != nil {
		return nil, err
	}

	updates, err := listUpdatesPacman()
	if err != nil {
		return nil, err
	}

	return &PkgInfo{installed, updates}, nil
}

func listPkgsPacman() (int, error) {
	files, err := os.ReadDir(installedPkgsPath)
	return len(files), err
}

func listUpdatesPacman() (int, error) {
	path := fmt.Sprintf("%s%s", os.Getenv("HOME"), availableUpdatesPath)
	file, err := os.ReadFile(path)
	if err != nil {
		return 0, err
	}
	return strconv.Atoi(strings.TrimSuffix(string(file), "\n"))
}
